//
//  ContentView.swift
//  DirectoryUI
//
//  Created by Joe Gregg on 10/24/22.
//

import SwiftUI

struct ContentView: View {
    @StateObject var directory : Directory = Directory()
    @State var isShowingDetailView = false
    
    var body: some View {
        NavigationStack {
            VStack {
                List {
                    ForEach(directory.people) { p in
                        HStack {
                            Text(p.name)
                            Spacer()
                            Text(p.office)
                        }
                    }.onDelete(perform:delete)
                }
            }.navigationDestination(isPresented: $isShowingDetailView, destination: {PersonView(d:directory)})
            .navigationTitle("Directory")
            .navigationBarTitleDisplayMode(.inline)
            .navigationBarItems(trailing: Button("+"){
                directory.makeNewPerson()
                isShowingDetailView = true;
            }
            )
        }
    }
    
    func delete(at offsets: IndexSet) {
        directory.delete(at:offsets)
        directory.saveChanges()
    }
}

#Preview {
    ContentView()
}
