//
//  Directory.swift
//  Directory
//
//  Created by Joe Gregg on 9/16/22.
//

import Foundation
import SwiftUI

class Directory : ObservableObject {
    @Published var people : [Person]
    @Published var newPerson : Person = Person(name:"",office:"")
    
    let itemArchiveURL: URL = {
        let documentsDirectories =
            FileManager.default.urls(for: .documentDirectory, in: .userDomainMask)
        let documentDirectory = documentsDirectories.first!
        return documentDirectory.appendingPathComponent("directory.plist")
    }()
    
    init() {
        do {
            let data = try Data(contentsOf: itemArchiveURL)
            let unarchiver = PropertyListDecoder()
            let loc = try unarchiver.decode(Array<Person>.self, from: data)
            people =  loc
        } catch {
            people =
            [Person(name:"Acacia Ackles",office:"Steitz 131"),
             Person(name:"Joe Gregg",office:"Briggs 413"),
             Person(name:"Kurt Krebsbach",office:"Briggs 411")
             ]
        }
    }
    
    func makeNewPerson() {
        newPerson = Person(name:"",office:"")
        people.append(newPerson)
        
    }
    
    func delete(at offsets: IndexSet) {
        people.remove(atOffsets: offsets)
    }
    
    func saveChanges() {
        do {
            let encoder = PropertyListEncoder()
            let data = try encoder.encode(people)
            try data.write(to: itemArchiveURL)
        } catch {
        }
    }

}
